API Reference
=============

This section documents the complete CVD Simulator API.

Core Module
-----------

.. automodule:: cvd_simulator
   :members:
   :undoc-members:
   :show-inheritance:

Configuration
-------------

.. automodule:: cvd_simulator.config
   :members:
   :undoc-members:
   :show-inheritance:

Enums
-----

.. automodule:: cvd_simulator.enums
   :members:
   :undoc-members:
   :show-inheritance:

Core Classes
------------

Simulator
~~~~~~~~~

.. automodule:: cvd_simulator.core.simulator
   :members:
   :undoc-members:
   :show-inheritance:

Image Loader
~~~~~~~~~~~~

.. automodule:: cvd_simulator.core.image_loader
   :members:
   :undoc-members:
   :show-inheritance:

Output Writer
~~~~~~~~~~~~~

.. automodule:: cvd_simulator.core.output_writer
   :members:
   :undoc-members:
   :show-inheritance:

Utilities
---------

Validators
~~~~~~~~~~

.. automodule:: cvd_simulator.utils.validators
   :members:
   :undoc-members:
   :show-inheritance:

Logging
~~~~~~~

.. automodule:: cvd_simulator.utils.logging_config
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: cvd_simulator.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

CLI Interface
-------------

.. automodule:: cvd_simulator.interfaces.cli
   :members:
   :undoc-members:
   :show-inheritance:
